@@ -1,5 +1,4 @@
-
-#define VERSION "0.2.4"
+#define VERSION "1.0.8"
 
 #define HAVE_STRING_H 1
 #define HAVE_STDLIB_H 1
@@ -29,3 +28,7 @@
 #pragma warning(disable : 4305)
 
 #define WITHOUT_SERVER 1
+
+#ifndef inline
+#define inline __inline
+#endif
