@@ -11,7 +11,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
@@ -55,9 +55,9 @@
 #define ALSA_SEQ_SCHED_PRIORITY 90
 
 /** fluid_alsa_audio_driver_t
- * 
+ *
  * This structure should not be accessed directly. Use audio port
- * functions instead.  
+ * functions instead.
  */
 typedef struct {
   fluid_audio_driver_t driver;
@@ -89,13 +89,13 @@ struct fluid_alsa_formats_t {
 };
 
 struct fluid_alsa_formats_t fluid_alsa_formats[] = {
-  { "s16, rw, interleaved", 
-    SND_PCM_FORMAT_S16, 
-    SND_PCM_ACCESS_RW_INTERLEAVED, 
+  { "s16, rw, interleaved",
+    SND_PCM_FORMAT_S16,
+    SND_PCM_ACCESS_RW_INTERLEAVED,
     fluid_alsa_audio_run_s16 },
-  { "float, rw, non interleaved", 
-    SND_PCM_FORMAT_FLOAT, 
-    SND_PCM_ACCESS_RW_NONINTERLEAVED, 
+  { "float, rw, non interleaved",
+    SND_PCM_FORMAT_FLOAT,
+    SND_PCM_ACCESS_RW_NONINTERLEAVED,
     fluid_alsa_audio_run_float },
   { NULL, 0, 0, NULL }
 };
@@ -118,8 +118,8 @@ typedef struct {
 } fluid_alsa_rawmidi_driver_t;
 
 
-fluid_midi_driver_t* new_fluid_alsa_rawmidi_driver(fluid_settings_t* settings, 
-						   handle_midi_event_func_t handler, 
+fluid_midi_driver_t* new_fluid_alsa_rawmidi_driver(fluid_settings_t* settings,
+						   handle_midi_event_func_t handler,
 						   void* event_handler_data);
 
 int delete_fluid_alsa_rawmidi_driver(fluid_midi_driver_t* p);
@@ -137,11 +137,11 @@ typedef struct {
   int npfd;
   pthread_t thread;
   int status;
-  int port_count;  
+  int port_count;
 } fluid_alsa_seq_driver_t;
 
-fluid_midi_driver_t* new_fluid_alsa_seq_driver(fluid_settings_t* settings, 
-					     handle_midi_event_func_t handler, 
+fluid_midi_driver_t* new_fluid_alsa_seq_driver(fluid_settings_t* settings,
+					     handle_midi_event_func_t handler,
 					     void* data);
 int delete_fluid_alsa_seq_driver(fluid_midi_driver_t* p);
 static void* fluid_alsa_seq_run(void* d);
@@ -158,16 +158,14 @@ void fluid_alsa_audio_driver_settings(fluid_settings_t* settings)
 }
 
 
-fluid_audio_driver_t* 
+fluid_audio_driver_t*
 new_fluid_alsa_audio_driver(fluid_settings_t* settings,
 			    fluid_synth_t* synth)
 {
-  return new_fluid_alsa_audio_driver2(settings, 
-				      (fluid_audio_func_t) fluid_synth_process, 
-				      synth);
+  return new_fluid_alsa_audio_driver2(settings, NULL, synth);
 }
 
-fluid_audio_driver_t* 
+fluid_audio_driver_t*
 new_fluid_alsa_audio_driver2(fluid_settings_t* settings,
 			     fluid_audio_func_t func, void* data)
 {
@@ -187,7 +185,7 @@ new_fluid_alsa_audio_driver2(fluid_settings_t* settings,
   dev = FLUID_NEW(fluid_alsa_audio_driver_t);
   if (dev == NULL) {
     FLUID_LOG(FLUID_ERR, "Out of memory");
-    return NULL;    
+    return NULL;
   }
   FLUID_MEMSET(dev, 0, sizeof(fluid_alsa_audio_driver_t));
 
@@ -200,7 +198,6 @@ new_fluid_alsa_audio_driver2(fluid_settings_t* settings,
   dev->callback = func;
   dev->cont = 1;
   dev->buffer_size = period_size;
-  uframes = period_size;
 
   /* Open the PCM device */
   if ((err = snd_pcm_open(&dev->pcm, device, SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK)) != 0) {
@@ -225,54 +222,57 @@ new_fluid_alsa_audio_driver2(fluid_settings_t* settings,
 
     snd_pcm_hw_params_any(dev->pcm, hwparams);
 
-    if (snd_pcm_hw_params_set_access(dev->pcm, hwparams, fluid_alsa_formats[i].access) != 0) {
+    if (snd_pcm_hw_params_set_access(dev->pcm, hwparams, fluid_alsa_formats[i].access) < 0) {
       continue;
     }
 
-    if (snd_pcm_hw_params_set_format(dev->pcm, hwparams, fluid_alsa_formats[i].format) != 0) {
+    if (snd_pcm_hw_params_set_format(dev->pcm, hwparams, fluid_alsa_formats[i].format) < 0) {
       continue;
     }
 
-    if ((err = snd_pcm_hw_params_set_channels(dev->pcm, hwparams, 2)) != 0) {
+    if ((err = snd_pcm_hw_params_set_channels(dev->pcm, hwparams, 2)) < 0) {
       FLUID_LOG(FLUID_ERR, "Failed to set the channels: %s",
 		snd_strerror (err));
-      goto error_recovery;    
+      goto error_recovery;
     }
 
     tmp = (unsigned int) sample_rate;
-    if ((err = snd_pcm_hw_params_set_rate_near(dev->pcm, hwparams, &tmp, &dir)) != 0) {
+    if ((err = snd_pcm_hw_params_set_rate_near(dev->pcm, hwparams, &tmp, NULL)) < 0) {
       FLUID_LOG(FLUID_ERR, "Failed to set the sample rate: %s",
 		snd_strerror (err));
-      goto error_recovery;    
-    }
-    if (dir != 0) {
-      /* There's currently no way to change the sampling rate of the
-	 synthesizer after it's been created. */
-      FLUID_LOG(FLUID_WARN, "The sample rate is set to %d, "
-		"the synthesizer may be out of tune", tmp);
+      goto error_recovery;
     }
 
-    if (snd_pcm_hw_params_set_period_size_near(dev->pcm, hwparams, &uframes, &dir) != 0) {
+    if (tmp != sample_rate) {
+      /* There's currently no way to change the sampling rate of the
+	 synthesizer after it's been created. */
+      FLUID_LOG(FLUID_WARN, "Requested sample rate of %d, got %d instead, "
+		"synthesizer likely out of tune!", sample_rate, tmp);
+    }
+
+    uframes = period_size;
+    if (snd_pcm_hw_params_set_period_size_near(dev->pcm, hwparams, &uframes, &dir) < 0) {
       FLUID_LOG(FLUID_ERR, "Failed to set the period size");
-      goto error_recovery;          
+      goto error_recovery;
     }
     if (uframes != (unsigned long) period_size) {
-      FLUID_LOG(FLUID_WARN, "Requested a period size of %d, got %d instead", 
+      FLUID_LOG(FLUID_WARN, "Requested a period size of %d, got %d instead",
 		period_size, (int) uframes);
       dev->buffer_size = (int) uframes;
+      period_size = uframes;	/* period size is used below, so set it to the real value */
     }
 
     tmp = periods;
-    if (snd_pcm_hw_params_set_periods_near(dev->pcm, hwparams, &tmp, &dir) != 0) {
+    if (snd_pcm_hw_params_set_periods_near(dev->pcm, hwparams, &tmp, &dir) < 0) {
       FLUID_LOG(FLUID_ERR, "Failed to set the number of periods");
-      goto error_recovery;          
+      goto error_recovery;
     }
     if (tmp != (unsigned int) periods) {
-      FLUID_LOG(FLUID_WARN, "Requested %d periods, got %d instead", 
+      FLUID_LOG(FLUID_WARN, "Requested %d periods, got %d instead",
 		periods, (int) tmp);
     }
-    
-    if (snd_pcm_hw_params(dev->pcm, hwparams) != 0) {
+
+    if (snd_pcm_hw_params(dev->pcm, hwparams) < 0) {
       FLUID_LOG(FLUID_WARN, "Audio device hardware configuration failed");
       continue;
     }
@@ -282,41 +282,45 @@ new_fluid_alsa_audio_driver2(fluid_settings_t* settings,
 
   if (fluid_alsa_formats[i].name == NULL) {
     FLUID_LOG(FLUID_ERR, "Failed to find a workable audio format");
-    goto error_recovery;    
+    goto error_recovery;
   }
 
   FLUID_LOG(FLUID_INFO, "ALSA driver: Using format %s", fluid_alsa_formats[i].name);
 
   /* Set the software params */
   snd_pcm_sw_params_current(dev->pcm, swparams);
-	
+
   if (snd_pcm_sw_params_set_start_threshold(dev->pcm, swparams, period_size) != 0) {
-    FLUID_LOG(FLUID_ERR, "Cannot turn off start threshold.");
+    FLUID_LOG(FLUID_ERR, "Failed to set start threshold.");
   }
-  
-  if (snd_pcm_sw_params_set_stop_threshold(dev->pcm, swparams, ~0u) != 0) {
-    FLUID_LOG(FLUID_ERR, "Cannot turn off stop threshold.");
-  }
-  
-  if (snd_pcm_sw_params_set_silence_threshold(dev->pcm, swparams, 0) != 0) {
-    FLUID_LOG(FLUID_ERR, "Cannot set 0 silence threshold.");
-  }
-  
-  if (snd_pcm_sw_params_set_silence_size(dev->pcm, swparams, 0) != 0) {
-    FLUID_LOG(FLUID_ERR, "Cannot set 0 silence size.");
-  }
-  
-  if (snd_pcm_sw_params_set_avail_min(dev->pcm, swparams, period_size / 2) != 0) {
+
+  /* FIXME - Any of these calls important?  One of them was causing massive
+     ALSA CPU consumption! */
+
+//  if (snd_pcm_sw_params_set_stop_threshold(dev->pcm, swparams, ~0u) != 0) {
+//    FLUID_LOG(FLUID_ERR, "Cannot turn off stop threshold.");
+//  }
+
+//  if (snd_pcm_sw_params_set_silence_threshold(dev->pcm, swparams, 0) != 0) {
+//    FLUID_LOG(FLUID_ERR, "Cannot set 0 silence threshold.");
+//  }
+
+//  if (snd_pcm_sw_params_set_silence_size(dev->pcm, swparams, 0) != 0) {
+//    FLUID_LOG(FLUID_ERR, "Cannot set 0 silence size.");
+//  }
+
+//  if (snd_pcm_sw_params_set_avail_min(dev->pcm, swparams, period_size / 2) != 0) {
+  if (snd_pcm_sw_params_set_avail_min(dev->pcm, swparams, period_size) != 0) {
     FLUID_LOG(FLUID_ERR, "Software setup for minimum available frames failed.");
   }
-  
+
   if (snd_pcm_sw_params(dev->pcm, swparams) != 0) {
     FLUID_LOG(FLUID_ERR, "Software setup failed.");
   }
 
 
   /* Create the audio thread */
-  
+
   if (pthread_attr_init(&attr)) {
     FLUID_LOG(FLUID_ERR, "Couldn't initialize audio thread attributes");
     goto error_recovery;
@@ -368,7 +372,7 @@ new_fluid_alsa_audio_driver2(fluid_settings_t* settings,
 int delete_fluid_alsa_audio_driver(fluid_audio_driver_t* p)
 {
   fluid_alsa_audio_driver_t* dev = (fluid_alsa_audio_driver_t*) p;
-  
+
   if (dev == NULL) {
     return FLUID_OK;
   }
@@ -390,6 +394,7 @@ int delete_fluid_alsa_audio_driver(fluid_audio_driver_t* p)
 	|| (state == SND_PCM_STATE_PAUSED)) {
       snd_pcm_drop(dev->pcm);
     }
+    snd_pcm_close (dev->pcm);
   }
 
   FLUID_FREE(dev);
@@ -397,9 +402,39 @@ int delete_fluid_alsa_audio_driver(fluid_audio_driver_t* p)
   return FLUID_OK;
 }
 
+/* handle error after an ALSA write call */
+static int fluid_alsa_handle_write_error (snd_pcm_t *pcm, int errval)
+{
+  switch (errval)
+  {
+  case -EAGAIN:
+    snd_pcm_wait(pcm, 1);
+    break;
+  case -EPIPE:
+  case -EBADFD:
+    if (snd_pcm_prepare(pcm) != 0) {
+      FLUID_LOG(FLUID_ERR, "Failed to prepare the audio device");
+      return FLUID_FAILED;
+    }
+    break;
+  case -ESTRPIPE:
+    if ((snd_pcm_resume(pcm) != 0) && (snd_pcm_prepare(pcm) != 0)) {
+      FLUID_LOG(FLUID_ERR, "Failed to resume the audio device");
+      return FLUID_FAILED;
+    }
+    break;
+  default:
+    FLUID_LOG(FLUID_ERR, "The audio device error: %s", snd_strerror(errval));
+    return FLUID_FAILED;
+  }
+
+  return FLUID_OK;
+}
+
 static void* fluid_alsa_audio_run_float(void* d)
 {
   fluid_alsa_audio_driver_t* dev = (fluid_alsa_audio_driver_t*) d;
+  fluid_synth_t *synth = (fluid_synth_t *)(dev->data);
   float* left;
   float* right;
   float* handle[2];
@@ -415,63 +450,63 @@ static void* fluid_alsa_audio_run_float(void* d)
     return NULL;
   }
 
-  handle[0] = left;
-  handle[1] = right;
-
   if (snd_pcm_nonblock(dev->pcm, 0) != 0) { /* double negation */
     FLUID_LOG(FLUID_ERR, "Failed to set the audio device to blocking mode");
-    goto error_recovery;    
+    goto error_recovery;
   }
 
   if (snd_pcm_prepare(dev->pcm) != 0) {
     FLUID_LOG(FLUID_ERR, "Failed to prepare the audio device");
-    goto error_recovery;    
+    goto error_recovery;
   }
 
-  while (dev->cont) {
+  /* use separate loops depending on if callback supplied or not (overkill?) */
+  if (dev->callback)
+  {
+    while (dev->cont) {
+      handle[0] = left;
+      handle[1] = right;
 
-    handle[0] = left;
-    handle[1] = right;
+      (*dev->callback)(synth, buffer_size, 0, NULL, 2, handle);
 
-    (*dev->callback)(dev->data, buffer_size, 0, NULL, 2, handle);
-    
-    offset = 0;
+      offset = 0;
+      while (offset < buffer_size) {
+	handle[0] = left + offset;
+	handle[1] = right + offset;
 
-    while (offset < buffer_size) {
+	n = snd_pcm_writen(dev->pcm, (void *)handle, buffer_size - offset);
 
-      handle[0] = left + offset;
-      handle[1] = right + offset;
-
-      n = snd_pcm_writen(dev->pcm, (void**) handle, buffer_size - offset);
-    
-      if (n == -EAGAIN) {
-	snd_pcm_wait(dev->pcm, 1);
-
-      } else if ((n == -EPIPE) || (n == -EBADFD)) {
-	if (snd_pcm_prepare(dev->pcm) != 0) {
-	  FLUID_LOG(FLUID_ERR, "Failed to prepare the audio device");
-	  goto error_recovery;    
-	}
-
-      } else if (n == -ESTRPIPE) {
-	if ((snd_pcm_resume(dev->pcm) != 0) 
-	    && (snd_pcm_prepare(dev->pcm) != 0)) {
-	  FLUID_LOG(FLUID_ERR, "Failed to resume the audio device");
-	  goto error_recovery;    
-	}
-
-      } else if (n < 0) {
-	  FLUID_LOG(FLUID_ERR, "The audio device error: %s", snd_strerror(n));
-	  goto error_recovery;    	
-
-      } else {
-	offset += n;
-      }
-    }  
+	if (n < 0)	/* error occurred? */
+	{
+	  if (fluid_alsa_handle_write_error (dev->pcm, n) != FLUID_OK)
+	    goto error_recovery;
+	} else offset += n;	/* no error occurred */
+      }	/* while (offset < buffer_size) */
+    }	/* while (dev->cont) */
   }
-  
+  else	/* no user audio callback (faster) */
+  {
+    while (dev->cont) {
+      fluid_synth_write_float(dev->data, buffer_size, left, 0, 1, right, 0, 1);
+
+      offset = 0;
+      while (offset < buffer_size) {
+	handle[0] = left + offset;
+	handle[1] = right + offset;
+
+	n = snd_pcm_writen(dev->pcm, (void *)handle, buffer_size - offset);
+
+	if (n < 0)	/* error occurred? */
+	{
+	  if (fluid_alsa_handle_write_error (dev->pcm, n) != FLUID_OK)
+	    goto error_recovery;
+	} else offset += n;	/* no error occurred */
+      }	/* while (offset < buffer_size) */
+    }	/* while (dev->cont) */
+  }
+
  error_recovery:
-  
+
   FLUID_FREE(left);
   FLUID_FREE(right);
 
@@ -509,63 +544,61 @@ static void* fluid_alsa_audio_run_s16(void* d)
 
   if (snd_pcm_prepare(dev->pcm) != 0) {
     FLUID_LOG(FLUID_ERR, "Failed to prepare the audio device");
-    goto error_recovery;    
+    goto error_recovery;
   }
 
-  while (dev->cont) {
+  /* use separate loops depending on if callback supplied or not */
+  if (dev->callback)
+  {
+    int dither_index = 0;
 
-    handle[0] = left;
-    handle[1] = right;
+    while (dev->cont)
+    {
+      (*dev->callback)(dev->data, buffer_size, 0, NULL, 2, handle);
 
-    (*dev->callback)(dev->data, buffer_size, 0, NULL, 2, handle);
-
-    for (i = 0, k = 0; i < buffer_size; i++, k += 2) {
-      s = 32768.0f * left[i];
-      fluid_clip(s, -32768.0f, 32767.0f);
-      buf[k] = (short) s;
-    }
-
-    for (i = 0, k = 1; i < buffer_size; i++, k += 2) {
-      s = 32768.0f * right[i];
-      fluid_clip(s, -32768.0f, 32767.0f);
-      buf[k] = (short) s;
-    }
-    
-    offset = 0;
-
-    while (offset < buffer_size) {
-
-      n = snd_pcm_writei(dev->pcm, (void*) (buf + 2 * offset), buffer_size - offset);
-
-      if (n == -EAGAIN) {
-	snd_pcm_wait(dev->pcm, 1);
-
-      } else if ((n == -EPIPE) || (n == -EBADFD)) {
-	if (snd_pcm_prepare(dev->pcm) != 0) {
-	  FLUID_LOG(FLUID_ERR, "Failed to prepare the audio device");
-	  goto error_recovery;    
+      /* convert floating point data to 16 bit (with dithering) */
+      fluid_synth_dither_s16 (&dither_index, buffer_size, left, right,
+			      buf, 0, 2, buf, 1, 2);
+      offset = 0;
+      while (offset < buffer_size)
+      {
+	n = snd_pcm_writei (dev->pcm, (void*) (buf + 2 * offset),
+			    buffer_size - offset);
+	if (n < 0)	/* error occurred? */
+	{
+	  if (fluid_alsa_handle_write_error (dev->pcm, n) != FLUID_OK)
+	    goto error_recovery;
 	}
-
-      } else if (n == -ESTRPIPE) {
-	if ((snd_pcm_resume(dev->pcm) != 0) 
-	    && (snd_pcm_prepare(dev->pcm) != 0)) {
-	  FLUID_LOG(FLUID_ERR, "Failed to resume the audio device");
-	  goto error_recovery;    
-	}
-
-      } else if (n < 0) {
-	  FLUID_LOG(FLUID_ERR, "The audio device error: %s", snd_strerror(n));
-	  goto error_recovery;    	
-
-      } else {
-	offset += n;
-      }
-    }  
-
+	else offset += n;	/* no error occurred */
+      }	/* while (offset < buffer_size) */
+    }	/* while (dev->cont) */
   }
-  
+  else	/* no user audio callback, dev->data is the synth instance */
+  {
+    fluid_synth_t* synth = (fluid_synth_t *)(dev->data);
+
+    while (dev->cont)
+    {
+      fluid_synth_write_s16 (synth, buffer_size, buf, 0, 2, buf, 1, 2);
+
+      offset = 0;
+      while (offset < buffer_size)
+      {
+	n = snd_pcm_writei (dev->pcm, (void*) (buf + 2 * offset),
+			    buffer_size - offset);
+
+	if (n < 0)	/* error occurred? */
+	{
+	  if (fluid_alsa_handle_write_error (dev->pcm, n) != FLUID_OK)
+	    goto error_recovery;
+	}
+	else offset += n;	/* no error occurred */
+      }	/* while (offset < buffer_size) */
+    }	/* while (dev->cont) */
+  }
+
  error_recovery:
-  
+
   FLUID_FREE(left);
   FLUID_FREE(right);
   FLUID_FREE(buf);
@@ -589,9 +622,9 @@ void fluid_alsa_rawmidi_driver_settings(fluid_settings_t* settings)
 /*
  * new_fluid_alsa_rawmidi_driver
  */
-fluid_midi_driver_t* 
-new_fluid_alsa_rawmidi_driver(fluid_settings_t* settings, 
-			     handle_midi_event_func_t handler, 
+fluid_midi_driver_t*
+new_fluid_alsa_rawmidi_driver(fluid_settings_t* settings,
+			     handle_midi_event_func_t handler,
 			     void* data)
 {
   int i, err;
@@ -652,8 +685,8 @@ new_fluid_alsa_rawmidi_driver(fluid_settings_t* settings,
   for (i = 0; i < count; i++) {		/* loop over file descriptors */
     if (pfd[i].events & POLLIN) { /* use only the input FDs */
       dev->pfd[dev->npfd].fd = pfd[i].fd;
-      dev->pfd[dev->npfd].events = POLLIN; 
-      dev->pfd[dev->npfd].revents = 0; 
+      dev->pfd[dev->npfd].events = POLLIN;
+      dev->pfd[dev->npfd].revents = 0;
       dev->npfd++;
     }
   }
@@ -669,14 +702,14 @@ new_fluid_alsa_rawmidi_driver(fluid_settings_t* settings,
 
   /* Was: "use fifo scheduling. if it fails, use default scheduling." */
   /* Now normal scheduling is used by default for the MIDI thread. The reason is,
-   * that fluidsynth works better with low latencies under heavy load, if only the 
+   * that fluidsynth works better with low latencies under heavy load, if only the
    * audio thread is prioritized.
    * With MIDI at ordinary priority, that could result in individual notes being played
    * a bit late. On the other hand, if the audio thread is delayed, an audible dropout
    * is the result.
    * To reproduce this: Edirol UA-1 USB-MIDI interface, four buffers
    * with 45 samples each (roughly 4 ms latency), ravewave soundfont. -MN
-   */ 
+   */
 
   /* Not so sure anymore. We're losing MIDI data, if we can't keep up with
    * the speed it is generated. */
@@ -712,19 +745,19 @@ new_fluid_alsa_rawmidi_driver(fluid_settings_t* settings,
       }
     }
     break;
-  }  
+  }
   return (fluid_midi_driver_t*) dev;
-  
+
  error_recovery:
   delete_fluid_alsa_rawmidi_driver((fluid_midi_driver_t*) dev);
   return NULL;
-  
+
 }
 
 /*
  * delete_fluid_alsa_rawmidi_driver
  */
-int 
+int
 delete_fluid_alsa_rawmidi_driver(fluid_midi_driver_t* p)
 {
   fluid_alsa_rawmidi_driver_t* dev;
@@ -760,7 +793,7 @@ delete_fluid_alsa_rawmidi_driver(fluid_midi_driver_t* p)
 /*
  * fluid_alsa_midi_run
  */
-void* 
+void*
 fluid_alsa_midi_run(void* d)
 {
   int n, i;
@@ -801,7 +834,7 @@ fluid_alsa_midi_run(void* d)
 	  (*dev->driver.handler)(dev->driver.data, evt);
 	}
       }
-    };
+    }
   }
   pthread_exit(NULL);
 }
@@ -836,7 +869,7 @@ static char* fluid_alsa_seq_full_id(char* id, char* buf, int len)
 }
 
 static char* fluid_alsa_seq_full_name(char* id, int port, char* buf, int len)
-{  
+{
   if (id != NULL) {
     if (FLUID_STRCMP(id, "pid") == 0) {
       snprintf(buf, len, "Synth input port (%d:%d)", getpid(), port);
@@ -853,8 +886,8 @@ static char* fluid_alsa_seq_full_name(char* id, int port, char* buf, int len)
 /*
  * new_fluid_alsa_seq_driver
  */
-fluid_midi_driver_t* 
-new_fluid_alsa_seq_driver(fluid_settings_t* settings, 
+fluid_midi_driver_t*
+new_fluid_alsa_seq_driver(fluid_settings_t* settings,
 			 handle_midi_event_func_t handler, void* data)
 {
   int i, err;
@@ -901,8 +934,8 @@ new_fluid_alsa_seq_driver(fluid_settings_t* settings,
     id = id_pid;
   }
 
-  /* open the sequencer INPUT only, non-blocking */
-  err = snd_seq_open(&dev->seq_handle, device, SND_SEQ_OPEN_INPUT, SND_SEQ_NONBLOCK);
+  /* open the sequencer INPUT only */
+  err = snd_seq_open(&dev->seq_handle, device, SND_SEQ_OPEN_INPUT, 0);
   if (err < 0) {
     FLUID_LOG(FLUID_ERR, "Error opening ALSA sequencer");
     goto error_recovery;
@@ -921,13 +954,13 @@ new_fluid_alsa_seq_driver(fluid_settings_t* settings,
   for (i = 0; i < count; i++) {		/* loop over file descriptors */
     if (pfd[i].events & POLLIN) { /* use only the input FDs */
       dev->pfd[dev->npfd].fd = pfd[i].fd;
-      dev->pfd[dev->npfd].events = POLLIN; 
-      dev->pfd[dev->npfd].revents = 0; 
+      dev->pfd[dev->npfd].events = POLLIN;
+      dev->pfd[dev->npfd].revents = 0;
       dev->npfd++;
     }
   }
   FLUID_FREE(pfd);
-  
+
   /* set the client name */
   snd_seq_set_client_name(dev->seq_handle, fluid_alsa_seq_full_id(id, full_id, 64));
 
@@ -939,11 +972,11 @@ new_fluid_alsa_seq_driver(fluid_settings_t* settings,
   fluid_settings_getint(settings, "synth.midi-channels", &midi_channels);
   dev->port_count = midi_channels / 16;
 
-  snd_seq_port_info_set_capability(port_info, 
-				   SND_SEQ_PORT_CAP_WRITE | 
+  snd_seq_port_info_set_capability(port_info,
+				   SND_SEQ_PORT_CAP_WRITE |
 				   SND_SEQ_PORT_CAP_SUBS_WRITE);
-  snd_seq_port_info_set_type(port_info, 
-			     SND_SEQ_PORT_TYPE_APPLICATION);
+  snd_seq_port_info_set_type(port_info,
+			     SND_SEQ_PORT_TYPE_MIDI_GENERIC | SND_SEQ_PORT_TYPE_APPLICATION);
   snd_seq_port_info_set_midi_channels(port_info, 16);
   snd_seq_port_info_set_port_specified(port_info, 1);
 
@@ -1006,7 +1039,7 @@ new_fluid_alsa_seq_driver(fluid_settings_t* settings,
       }
     }
     break;
-  }  
+  }
   return (fluid_midi_driver_t*) dev;
 
  error_recovery:
@@ -1017,7 +1050,7 @@ new_fluid_alsa_seq_driver(fluid_settings_t* settings,
 /*
  * delete_fluid_alsa_seq_driver
  */
-int 
+int
 delete_fluid_alsa_seq_driver(fluid_midi_driver_t* p)
 {
   fluid_alsa_seq_driver_t* dev;
@@ -1043,6 +1076,9 @@ delete_fluid_alsa_seq_driver(fluid_midi_driver_t* p)
   if (dev->seq_handle) {
     snd_seq_close(dev->seq_handle);
   }
+
+  if (dev->pfd) FLUID_FREE (dev->pfd);
+
   FLUID_FREE(dev);
   return FLUID_OK;
 }
@@ -1050,10 +1086,10 @@ delete_fluid_alsa_seq_driver(fluid_midi_driver_t* p)
 /*
  * fluid_alsa_seq_run
  */
-void* 
+void*
 fluid_alsa_seq_run(void* d)
 {
-  int n, i;
+  int n, ev;
   snd_seq_event_t *seq_ev;
   fluid_midi_event_t evt;
   fluid_alsa_seq_driver_t* dev = (fluid_alsa_seq_driver_t*) d;
@@ -1074,15 +1110,27 @@ fluid_alsa_seq_run(void* d)
   while (dev->status == FLUID_MIDI_LISTENING) {
 
     /* is there something to read? */
-    n = poll(dev->pfd, dev->npfd, 1); /* use a 1 milliseconds timeout */
+    n = poll(dev->pfd, dev->npfd, 100); /* use a 100 milliseconds timeout */
     if (n < 0) {
       perror("poll");
-    } else if (n > 0) {
-
-      /* read new events */
-      while ((n = snd_seq_event_input(dev->seq_handle, &seq_ev)) >= 0)
+    } else if (n > 0) {      /* check for pending events */
+      do
 	{
-	  switch (seq_ev->type)
+	    ev = snd_seq_event_input(dev->seq_handle, &seq_ev);	/* read the events */
+
+	    /* Negative value indicates an error, ignore interrupted system call
+	     * (-EPERM) and input event buffer overrun (-ENOSPC) */
+	    if (ev < 0)
+	    {	/* FIXME - report buffer overrun? */
+		if (ev != -EPERM && ev != -ENOSPC)
+		{
+		  FLUID_LOG(FLUID_ERR, "Error while reading ALSA sequencer (code=%d)", ev);
+		  dev->status = FLUID_MIDI_DONE;
+		}
+		break;
+	    }
+
+	    switch (seq_ev->type)
 	    {
 	    case SND_SEQ_EVENT_NOTEON:
 	      evt.type = NOTE_ON;
@@ -1129,24 +1177,12 @@ fluid_alsa_seq_run(void* d)
 	      continue;		/* unhandled event, next loop iteration */
 	    }
 
-	  /* send the events to the next link in the chain */
-	  (*dev->driver.handler)(dev->driver.data, &evt);
+	    /* send the events to the next link in the chain */
+	    (*dev->driver.handler)(dev->driver.data, &evt);
 	}
-    }
-
-    if (n < 0)		/* Negative value indicates an error */
-    {
-      if (n == -EPERM)		/* interrupted system call? */
-	;
-      else if (n != -ENOSPC)	/* input event buffer overrun? */
-	FLUID_LOG(FLUID_WARN, "ALSA sequencer buffer overrun, lost events");
-      else
-      {
-	FLUID_LOG(FLUID_ERR, "Error occured while reading ALSA sequencer events (code=%d)", n);
-	dev->status = FLUID_MIDI_DONE;
-      }
-    }
-  }
+	while (ev > 0);
+    }	/* if poll() > 0 */
+  }	/* while (dev->status == FLUID_MIDI_LISTENING) */
   pthread_exit(NULL);
 }
 
