@@ -11,7 +11,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
@@ -19,18 +19,21 @@
  */
 
 #include "fluidsynth_priv.h"
-#include "fluid_settings.h"
+#include "fluid_sys.h"
 #include "fluid_hash.h"
-#include "fluid_strtok.h"
 #include "fluid_synth.h"
 #include "fluid_cmd.h"
 #include "fluid_adriver.h"
 #include "fluid_mdriver.h"
+#include "fluid_settings.h"
 
+/* maximum allowed components of a settings variable (separated by '.') */
+#define MAX_SETTINGS_TOKENS	8	/* currently only a max of 3 are used */
+#define MAX_SETTINGS_LABEL	256	/* max length of a settings variable label */
 
 static void fluid_settings_init(fluid_settings_t* settings);
 static void fluid_settings_hash_delete(void* value, int type);
-static int fluid_settings_tokenize(char* s, char* buf, char** ptr);
+static int fluid_settings_tokenize(char* s, char *buf, char** ptr);
 
 
 typedef struct {
@@ -42,7 +45,7 @@ typedef struct {
   void* data;
 } fluid_str_setting_t;
 
-static fluid_str_setting_t* 
+static fluid_str_setting_t*
 new_fluid_str_setting(char* value, char* def, int hints, fluid_str_update_t fun, void* data)
 {
   fluid_str_setting_t* str;
@@ -60,13 +63,20 @@ static void delete_fluid_str_setting(fluid_str_setting_t* str)
 {
   if (str) {
     if (str->value) {
-      FLUID_FREE(str->value);      
+      FLUID_FREE(str->value);
     }
     if (str->def) {
-      FLUID_FREE(str->def);      
+      FLUID_FREE(str->def);
     }
     if (str->options) {
-      delete_fluid_list(str->options);      
+      fluid_list_t* list = str->options;
+
+      while (list) {
+	FLUID_FREE (list->data);
+	list = fluid_list_next(list);
+      }
+
+      delete_fluid_list(str->options);
     }
     FLUID_FREE(str);
   }
@@ -86,7 +96,7 @@ typedef struct {
 } fluid_num_setting_t;
 
 
-static fluid_num_setting_t* 
+static fluid_num_setting_t*
 new_fluid_num_setting(double min, double max, double def,
 		     int hints, fluid_num_update_t fun, void* data)
 {
@@ -123,7 +133,7 @@ typedef struct {
 } fluid_int_setting_t;
 
 
-static fluid_int_setting_t* 
+static fluid_int_setting_t*
 new_fluid_int_setting(int min, int max, int def,
 		     int hints, fluid_int_update_t fun, void* data)
 {
@@ -189,37 +199,46 @@ void fluid_settings_init(fluid_settings_t* settings)
   fluid_midi_driver_settings(settings);
 }
 
-static fluid_strtok_t* fluid_settings_strtok = NULL;
-
-int fluid_settings_tokenize(char* s, char* buf, char** ptr)
+static int fluid_settings_tokenize(char* s, char *buf, char** ptr)
 {
+  char *tokstr, *tok;
   int n = 0;
 
-  FLUID_STRCPY(buf, s);
-
-  if (fluid_settings_strtok == NULL) {
-    fluid_settings_strtok = new_fluid_strtok(buf, ".");
-  } else {
-    fluid_strtok_set(fluid_settings_strtok, buf, ".");
+  if (strlen (s) > MAX_SETTINGS_LABEL)
+  {
+    FLUID_LOG(FLUID_ERR, "Setting variable name exceeded max length of %d chars",
+	      MAX_SETTINGS_LABEL);
+    return 0;
   }
 
-  while (fluid_strtok_has_more(fluid_settings_strtok)) {
-    ptr[n++] = fluid_strtok_next_token(fluid_settings_strtok);
+  FLUID_STRCPY(buf, s);	/* copy string to buffer, since it gets modified */
+  tokstr = buf;
+
+  while ((tok = fluid_strtok (&tokstr, ".")))
+  {
+    if (n > MAX_SETTINGS_TOKENS)
+    {
+      FLUID_LOG(FLUID_ERR, "Setting variable name exceeded max token count of %d",
+		MAX_SETTINGS_TOKENS);
+      return 0;
+    }
+
+    ptr[n++] = tok;
   }
 
   return n;
 }
 
 /** returns 1 if the value exists, 0 otherwise */
-static int fluid_settings_get(fluid_settings_t* settings, 
-			     char** name, int len, 
+static int fluid_settings_get(fluid_settings_t* settings,
+			     char** name, int len,
 			     void** value, int* type)
 {
   fluid_hashtable_t* table = settings;
   int t;
   void* v;
   int n;
-  
+
   for (n = 0; n < len; n++) {
 
     if (table == NULL) {
@@ -244,10 +263,9 @@ static int fluid_settings_get(fluid_settings_t* settings,
   return 1;
 }
 
-
 /** returns 1 if the value has been set, zero otherwise */
-static int fluid_settings_set(fluid_settings_t* settings, 
-			     char** name, int len, 
+static int fluid_settings_set(fluid_settings_t* settings,
+			     char** name, int len,
 			     void* value, int type)
 {
   fluid_hashtable_t* table = settings;
@@ -276,29 +294,29 @@ static int fluid_settings_set(fluid_settings_t* settings,
     }
   }
 
-  fluid_hashtable_replace(table, name[num], value, type);	
+  fluid_hashtable_replace(table, name[num], value, type);
 
   return 1;
 }
 
-/** returns 1 if the value has been resgister correctly, 0
+/** returns 1 if the value has been registered correctly, 0
     otherwise */
 int fluid_settings_register_str(fluid_settings_t* settings, char* name, char* def, int hints,
 			       fluid_str_update_t fun, void* data)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
   fluid_str_setting_t* setting;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (!fluid_settings_get(settings, tokens, ntokens, &value, &type)) {    
+  if (!fluid_settings_get(settings, tokens, ntokens, &value, &type)) {
     setting = new_fluid_str_setting(def, def, hints, fun, data);
     return fluid_settings_set(settings, tokens, ntokens, setting, FLUID_STR_TYPE);
-    
+
   } else {
     /* if variable already exists, don't change its value. */
     if (type == FLUID_STR_TYPE) {
@@ -317,14 +335,14 @@ int fluid_settings_register_str(fluid_settings_t* settings, char* name, char* de
 
 /** returns 1 if the value has been register correctly, zero
     otherwise */
-int fluid_settings_register_num(fluid_settings_t* settings, char* name, double def, 
-			       double min, double max, int hints, 
+int fluid_settings_register_num(fluid_settings_t* settings, char* name, double def,
+			       double min, double max, int hints,
 			       fluid_num_update_t fun, void* data)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
@@ -357,14 +375,14 @@ int fluid_settings_register_num(fluid_settings_t* settings, char* name, double d
 
 /** returns 1 if the value has been register correctly, zero
     otherwise */
-int fluid_settings_register_int(fluid_settings_t* settings, char* name, int def, 
-			       int min, int max, int hints, 
+int fluid_settings_register_int(fluid_settings_t* settings, char* name, int def,
+			       int min, int max, int hints,
 			       fluid_int_update_t fun, void* data)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
@@ -395,13 +413,12 @@ int fluid_settings_register_int(fluid_settings_t* settings, char* name, int def,
   }
 }
 
-
 int fluid_settings_get_type(fluid_settings_t* settings, char* name)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
@@ -409,13 +426,12 @@ int fluid_settings_get_type(fluid_settings_t* settings, char* name)
   return (fluid_settings_get(settings, tokens, ntokens, &value, &type))? type : FLUID_NO_TYPE;
 }
 
-
 int fluid_settings_get_hints(fluid_settings_t* settings, char* name)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
@@ -439,8 +455,8 @@ int fluid_settings_is_realtime(fluid_settings_t* settings, char* name)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
@@ -461,11 +477,10 @@ int fluid_settings_is_realtime(fluid_settings_t* settings, char* name)
   }
 }
 
-
 int fluid_settings_setstr(fluid_settings_t* settings, char* name, char* str)
 {
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
   int type;
   void* value;
@@ -474,7 +489,7 @@ int fluid_settings_setstr(fluid_settings_t* settings, char* name, char* str)
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
   if (fluid_settings_get(settings, tokens, ntokens, &value, &type)) {
-    
+
     if (type != FLUID_STR_TYPE) {
       return 0;
     }
@@ -485,14 +500,14 @@ int fluid_settings_setstr(fluid_settings_t* settings, char* name, char* str)
       FLUID_FREE(setting->value);
     }
     setting->value = str? FLUID_STRDUP(str) : NULL;
-    
+
     if (setting->update) {
       (*setting->update)(setting->data, name, setting->value);
     }
-    
+
     return 1;
 
-  } else { 
+  } else {
     /* insert a new setting */
     fluid_str_setting_t* setting;
     setting = new_fluid_str_setting(str, NULL, 0, NULL, NULL);
@@ -504,13 +519,13 @@ int fluid_settings_getstr(fluid_settings_t* settings, char* name, char** str)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_STR_TYPE)) {
     fluid_str_setting_t* setting = (fluid_str_setting_t*) value;
     *str = setting->value;
@@ -520,18 +535,17 @@ int fluid_settings_getstr(fluid_settings_t* settings, char* name, char** str)
   return 0;
 }
 
-
 int fluid_settings_str_equal(fluid_settings_t* settings, char* name, char* s)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_STR_TYPE)) {
     fluid_str_setting_t* setting = (fluid_str_setting_t*) value;
     return FLUID_STRCMP(setting->value, s) == 0;
@@ -539,19 +553,18 @@ int fluid_settings_str_equal(fluid_settings_t* settings, char* name, char* s)
   return 0;
 }
 
-
-char* 
+char*
 fluid_settings_getstr_default(fluid_settings_t* settings, char* name)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_STR_TYPE)) {
     fluid_str_setting_t* setting = (fluid_str_setting_t*) value;
     return setting->def;
@@ -564,13 +577,13 @@ int fluid_settings_add_option(fluid_settings_t* settings, char* name, char* s)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_STR_TYPE)) {
     fluid_str_setting_t* setting = (fluid_str_setting_t*) value;
     char* copy = FLUID_STRDUP(s);
@@ -578,20 +591,20 @@ int fluid_settings_add_option(fluid_settings_t* settings, char* name, char* s)
     return 1;
   } else {
     return 0;
-  }  
+  }
 }
 
 int fluid_settings_remove_option(fluid_settings_t* settings, char* name, char* s)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_STR_TYPE)) {
 
     fluid_str_setting_t* setting = (fluid_str_setting_t*) value;
@@ -600,6 +613,7 @@ int fluid_settings_remove_option(fluid_settings_t* settings, char* name, char* s
     while (list) {
       char* option = (char*) fluid_list_get(list);
       if (FLUID_STRCMP(s, option) == 0) {
+	FLUID_FREE (option);
 	setting->options = fluid_list_remove_link(setting->options, list);
 	return 1;
       }
@@ -609,17 +623,16 @@ int fluid_settings_remove_option(fluid_settings_t* settings, char* name, char* s
     return 0;
   } else {
     return 0;
-  }  
+  }
 }
 
-
 int fluid_settings_setnum(fluid_settings_t* settings, char* name, double val)
 {
   int type;
   void* value;
   fluid_num_setting_t* setting;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
@@ -631,22 +644,22 @@ int fluid_settings_setnum(fluid_settings_t* settings, char* name, double val)
     }
 
     setting = (fluid_num_setting_t*) value;
-    
+
     if (val < setting->min) {
       val = setting->min;
     } else if (val > setting->max) {
       val = setting->max;
     }
-    
+
     setting->value = val;
-    
+
     if (setting->update) {
       (*setting->update)(setting->data, name, val);
     }
-    
+
     return 1;
 
-  } else { 
+  } else {
     /* insert a new setting */
     fluid_num_setting_t* setting;
     setting = new_fluid_num_setting(-1e10, 1e10, 0.0f, 0, NULL, NULL);
@@ -659,13 +672,13 @@ int fluid_settings_getnum(fluid_settings_t* settings, char* name, double* val)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_NUM_TYPE)) {
     fluid_num_setting_t* setting = (fluid_num_setting_t*) value;
     *val = setting->value;
@@ -679,13 +692,13 @@ void fluid_settings_getnum_range(fluid_settings_t* settings, char* name, double*
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_NUM_TYPE)) {
     fluid_num_setting_t* setting = (fluid_num_setting_t*) value;
     *min = setting->min;
@@ -693,18 +706,18 @@ void fluid_settings_getnum_range(fluid_settings_t* settings, char* name, double*
   }
 }
 
-double 
+double
 fluid_settings_getnum_default(fluid_settings_t* settings, char* name)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_NUM_TYPE)) {
     fluid_num_setting_t* setting = (fluid_num_setting_t*) value;
     return setting->def;
@@ -719,8 +732,8 @@ int fluid_settings_setint(fluid_settings_t* settings, char* name, int val)
   int type;
   void* value;
   fluid_int_setting_t* setting;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
@@ -732,22 +745,22 @@ int fluid_settings_setint(fluid_settings_t* settings, char* name, int val)
     }
 
     setting = (fluid_int_setting_t*) value;
-    
+
     if (val < setting->min) {
       val = setting->min;
     } else if (val > setting->max) {
       val = setting->max;
     }
-    
+
     setting->value = val;
-    
+
     if (setting->update) {
       (*setting->update)(setting->data, name, val);
     }
-    
+
     return 1;
 
-  } else { 
+  } else {
     /* insert a new setting */
     fluid_int_setting_t* setting;
     setting = new_fluid_int_setting(INT_MIN, INT_MAX, 0, 0, NULL, NULL);
@@ -760,13 +773,13 @@ int fluid_settings_getint(fluid_settings_t* settings, char* name, int* val)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_INT_TYPE)) {
     fluid_int_setting_t* setting = (fluid_int_setting_t*) value;
     *val = setting->value;
@@ -780,13 +793,13 @@ void fluid_settings_getint_range(fluid_settings_t* settings, char* name, int* mi
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_INT_TYPE)) {
     fluid_int_setting_t* setting = (fluid_int_setting_t*) value;
     *min = setting->min;
@@ -799,13 +812,13 @@ fluid_settings_getint_default(fluid_settings_t* settings, char* name)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_INT_TYPE)) {
     fluid_int_setting_t* setting = (fluid_int_setting_t*) value;
     return setting->def;
@@ -817,13 +830,13 @@ fluid_settings_getint_default(fluid_settings_t* settings, char* name)
 
 
 
-void fluid_settings_foreach_option(fluid_settings_t* settings, char* name, void* data, 
+void fluid_settings_foreach_option(fluid_settings_t* settings, char* name, void* data,
 				  fluid_settings_foreach_option_t func)
 {
   int type;
   void* value;
-  char buf[1024];
-  char* tokens[16];
+  char* tokens[MAX_SETTINGS_TOKENS];
+  char buf[MAX_SETTINGS_LABEL+1];
   int ntokens;
 
   if (!func) {
@@ -832,7 +845,7 @@ void fluid_settings_foreach_option(fluid_settings_t* settings, char* name, void*
 
   ntokens = fluid_settings_tokenize(name, buf, tokens);
 
-  if (fluid_settings_get(settings, tokens, ntokens, &value, &type) 
+  if (fluid_settings_get(settings, tokens, ntokens, &value, &type)
       && (type == FLUID_STR_TYPE)) {
 
     fluid_str_setting_t* setting = (fluid_str_setting_t*) value;
@@ -843,7 +856,7 @@ void fluid_settings_foreach_option(fluid_settings_t* settings, char* name, void*
       (*func)(data, name, option);
       list = fluid_list_next(list);
     }
-  }  
+  }
 }
 
 
